@@ -63,7 +63,7 @@ def get_all_files(path):
 
 def main():
   if len(sys.argv) != 2:
-    print("Please enter the path to the root of your Git repository"
+    print("Please enter the path to the root of your Git repository")
 
   path = sys.argv[1]
   copyright_file_map = get_copyright_files_map(path)
